@@ -18,6 +18,40 @@ from departments.forms.forms import (
 from departments.utils.error_response import Resp
 
 
+def get_org_root_department(organization_id: int):
+    try:
+        instance = Department.objects.get(
+            organization_id=organization_id,
+            is_deleted=False,
+            path__isnull=True
+        )
+    except Department.DoesNotExist:
+        return None
+
+    return instance
+
+
+def update_org_root_department(organization_id: int, department_id: int, data: dict):
+
+    if 'parent_id' in data:
+        data.pop('parent_id')
+
+    instance = Department.objects.filter(
+        organization_id=organization_id,
+        pk=department_id,
+        path__isnull=True
+    )
+    if not instance:
+        return Resp(code=ServerErrorCode, msg=f'org : {organization_id} not found root department: {department_id}')
+
+    if instance.count() > 1:
+        return Resp(code=ServerErrorCode, msg=f'org : {organization_id} root department: {department_id} count failed')
+
+    instance.update(**data)
+
+    return instance.first()
+
+
 def get_departments(organization_id: int, department_name: str = None) -> dict:
     """
     通过组织id获取全量部门
