@@ -24,7 +24,7 @@ from departments.utils.department_funcs import (
     get_organization_users,
     exclude_department_users,
     user_change_department,
-    get_user_departments
+    get_user_departments, get_org_root_department, update_org_root_department
 )
 
 
@@ -35,6 +35,15 @@ class DepartmentControl(object):
             raise TypeError(f"organization_id is failed type ")
         self.organization_id = organization_id
 
+    @property
+    def root(self):
+        res = get_org_root_department(self.organization_id)
+        return res
+
+    @transaction.atomic
+    def update_root(self, department_id: int, data: dict):
+        return update_org_root_department(self.organization_id, department_id=department_id, data=data)
+
     def organization_user_list(self):
         """
         获取当前组织下所有的用户
